#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use CGI;
use Encode;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::Panel::Commons;
use Vhffs::Panel::Group;
use Vhffs::Panel::Main;
use Vhffs::Panel::Template;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;

my $vhffs = $panel->{'vhffs'};
my $templatedir = $panel->{'templatedir'};
my $cgi = $panel->{'cgi'};

$panel->check_public();

my $template = new Vhffs::Panel::Template( filename => $templatedir.'/public/groupslist.tmpl', die_on_bad_params => 0 );
my $groupname = $cgi->param('groupname') || '';
my $description = Encode::decode_utf8( $cgi->param('description') ) || '';
my $page = $cgi->param('page');
my $per_page_count = 5;
$page = 1 unless(defined $page && int($page) > 0);

my $result = Vhffs::Panel::Group::public_search(
    $vhffs,
    ( $groupname =~ /^\s*$/ ? undef : $groupname ),
    ( $description =~ /^\s*$/ ? undef : $description ),
    ($page -1) * $per_page_count,
    $per_page_count
);

$template->param( URL_PANEL => $vhffs->get_config->get_panel->{'url'} );

if($result->{total_count} == 0) {
    $template->param( TEXT_TITLE => gettext('No group found') );
} else {
    Vhffs::Panel::Commons::paginate($template, $page, $result->{total_count}, $per_page_count,
        { groupname => $groupname, description => $description });
    $template->param( USE_AVATAR => $panel->use_groups_avatars );
    $template->param( TEXT_TITLE => sprintf( gettext('%d group(s) found'), $result->{total_count} ) );
    $template->param( GROUPS => $result->{data} );
}

$panel->light( $template );
$panel->display;

